# QMe

"Queue-me" is a jobs queue and dashboard generation tool that can be used
to specify executors (entities that run jobs) and actions for them.

[![PyPI version](https://badge.fury.io/py/qme.svg)](https://badge.fury.io/py/qme)

**under development**

 * Free software: MPL 2.0 License
